@@ -1,4 +1,11 @@
 def define_coef(coefficients, zstep):
+    """
+    Retrieves respective heat transfer coefficients for certain depth point.
+    :param coefficients: list with distribution of heat transfer coefficients
+    :param zstep: depth step
+    :return: values of heat coefficients for each section at the same depth
+    """
+
     hc_1 = coefficients[0]
     c1z = hc_1[0][zstep]
     c1e = hc_1[1][zstep]
@@ -38,6 +45,14 @@ def define_coef(coefficients, zstep):
 
 
 def temp_calc(well, initcond, heatcoeff):
+    """
+    Build the penta-diagonal matrix and solve it to get the well temperature distribution.
+    :param well: a well object created from the function set_well()
+    :param initcond: object with initial temperature profiles
+    :param heatcoeff: list with distribution of heat transfer coefficients
+    :return: object with final well temperature distribution
+    """
+
     from numpy import zeros, linalg
 
     Tft = []
@@ -93,7 +108,7 @@ def temp_calc(well, initcond, heatcoeff):
                              + c1z * (initcond.tfto[j + 1] - initcond.tfto[j])  # N/S(t=0)
                              + c1z * initcond.tfto[-1])
 
-                if j == well.zstep - 1:     # Cell where fluid flows out of the tubing and then go to annular
+                if j == well.zstep - 1:
                     N.append(0)
                     W.append(0)
                     C.append(cbt + cbe)
@@ -135,7 +150,7 @@ def temp_calc(well, initcond, heatcoeff):
                              + c2z * (initcond.tto[j - 1] - initcond.tto[j])
                              + c2z * initcond.tfto[-1])
 
-                if j == well.zstep - 1:     # Cell where fluid flows out of the tubing and then go to annular
+                if j == well.zstep - 1:
                     N.append(-c2z)
                     W.append(0)
                     C.append(c2t + c2e + c2w + c2z)
@@ -180,7 +195,7 @@ def temp_calc(well, initcond, heatcoeff):
                                  + c3z * (initcond.tao[j - 1] - initcond.tao[j])
                                  + c3z * initcond.tfto[-1])
 
-                if j == well.zstep - 1:     # Cell where fluid flows out of the tubing and then go to annular
+                if j == well.zstep - 1:
                     N.append(-c3z)
                     W.append(0)
                     C.append(c3t + c3e + c3w + c3z)
